show = ValueError()
from requests import get as m
import vk_api
import os
import random
import re
import bot_vk
import time
def parse(s,pol=1):
    while "||" in s:
        ss= re.findall(".*\{(.*?)\|\|(.*?)\}.*",s )
        if ss == []:
            break
        boy,girl = ss[0] 
        ins= girl
        if pol !=1:
            ins =boy
        s = s.replace(r"{"+boy+r"||"+girl+r"}", ins)
    return s

def internet_on(site="https://vk.com"):
    """проверяет, включен ли интернет."""
    try:
        m(site)
        return True
    except: 
        return False
def auth_vk(token=None, login = None,password = None):
    "модуль для авторизации вконтакте."
    if internet_on() == True:
            
        if login!= None and password != None: 
            vk = vk_api.VkApi(login = login,password = password)
            vk.auth()
            return vk
        elif token!=None:
            vk = vk_api.VkApi(token = token)
            vk._auth_token()
            return vk
        elif password == None or password == "":
            raise show("НЕТ ПАРОЛЯ!!!")
        else:
            raise show("неправильные данные")
    else:
        raise show("подключение к интернету отсутствует")
def dele(file):
    """удаляет файл. ХЗ, зачем нужен, но он тут :3"""
    return os.remove(file)

def vk_bot(szenarii1,szenarii2,message_neznayu="я не знаю, как ответить(((",attachment_neznayu = "doc302808715_475715032",attachments=None,keyboard=None,vk = None,login = None,password = None,token = None):
    """
    модуль для создания чат-бота
    szenarii1 - list,в котором через запятую перечисленны варианты того, что
        пользователь может прислать(сценарии) 
    szenarii2 - list,  котором перечисленны ответы на szenarii1. ВАЖНО!!!
        Для каждого элемента szenarii1
        должен быть свой ответ. Можно использовать {firstname}, {lastname},{city} -
            будет превращено в имя, фамилию, город пользователя. Так же можно использовать {||}, который превратится в текст,
            в зависемости от пола пользователя - слева от || текст увидят мужчины, справа - женщины. Пример:
                szenarii1 = ["привет","ты кто?"]
                szenarii2 = ['Привет,{firstname} я - чат-бот, у которого есть команда "ты кто"',"теперь я просто чат-бот, а ты надеюсь, понял{||a} логику"]
    message_neznayu - str объект(сообщение), которое бот будет посылать на неизвестный сценарий.
    attachment_neznayu - str объект, attachment который бот будет посылать на неизвестный сценарий.
    
    attachments - или передавать None, или list, как и szenarii2, только для медиавложений. Если для какого-то сценария attachments отсутствует,
        то передовать пустой элемент. Пример:
            attachments = ["photo-165897409_456239349,photo-165897409_456239277",""]
    keyboard - или передавать None, или передавать list, в котором каждое значение соответствует
        клавиатуре для данного сценария. Если клавиатуры для какого-то сценария нет, то передавать bot_vk.keyboard.keyboard_none()
        
    vk - параметр bot_vk.auth_vk() Если не передан, то должн быть передан token или login и password
    login - login от вашего аккаунта вк. Передается вместе с password, если не передан vk
    password - пароль от вашего аккаунта вк. Передается вместе с логином
    token - токен группы или access token пользователя. Передается если не передан параметр vk, login, password 

    """
    if keyboard!= None:
        for i in range(len(keyboard)):
            if keyboard[i] == None:
                keyboard[i] = bot_vk.keyboard.keyboard_none()
    if keyboard==None:
            
            sinus = bot_vk.keyboard.keyboard_none()
            keyboard = [sinus]*len(szenarii1)
    if attachments == None:
            attachments = [""]*len(szenarii1)
    if internet_on() == True:
        
        if len(szenarii1) == len(szenarii2):
            
                
            """
            если параметр vk не передан, то создаем его используя логин и пароль, или токен.
            """
            if vk == None:
                if login!=None and password!=None:
                    vk = vk_api.VkApi(login = login,password = password)
                    vk.auth()
                elif token != None:
                    vk = vk_api.VkApi(token = token)
                    vk._auth_token()
                else:
                    raise show("нужен пароль с логином, или access token")

            id_own = vk.method("users.get",{})
            if id_own!=[]:
                id_own = id_own[0]["id"]
            def bot():
                info = vk.method("messages.getConversations",{"count":10})
                if info["count"]>0:
                    id = info["items"][0]["last_message"]["from_id"]
                    """проходим проверку, кто прислал сообщение, наш бот, или пользователь"""
                    if info["items"][0]["last_message"]["from_id"]>0:# and id_own != info["items"][0]["last_message"]["from_id"]:
                        
                        message = info["items"][0]["last_message"]["text"]
                        ininon = vk.method("users.get",{"user_ids":id,"fields":"id,city,sex"})[0]
                        if "city" in ininon:
                            city = ininon["city"]["title"]
                        else:
                            city = "Москва"
                        firstname = ininon["first_name"]
                        lastname =ininon["last_name"]
                        pol = ininon["sex"]
                        
                        
                        s = 1
                        for i in range(len(szenarii1)):
                            if s == 0:
                                break
                            mes =szenarii1[i]
                            if mes.lower() == message.lower():
                                s = 0
                                string = bot_vk.parse(szenarii2[i], pol).format(firstname=firstname,lastname=lastname,city=city)
                                
                                vk.method("messages.send",{"message":string.format(firstname=firstname,lastname=lastname),"user_id":id,"attachment": attachments[i],"keyboard":keyboard[i]})
                            
                        if s == 1:
                            string = bot_vk.parse(message_neznayu, pol).format(firstname=firstname,lastname=lastname,city=city)
                            vk.method("messages.send",{"message":string,"user_id":id,"attachment":attachment_neznayu})
                        
            """запускаем скрипт"""
            while True:
                try:
                    bot()
                except:
                    time.sleep(0.1)


                    
        else:
            raise show("длина массива со сценариями должна быть равна 2-му")



import re,lxml.html, requests,json,urllib,time
class audio(object):
        def __init__(self,login,password):
                url='https://vk.com/'
                headers = {
                    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/61.0.3163.100 Safari/537.36',
                    'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
                    'Accept-Language':'ru-ru,ru;q=0.8,en-us;q=0.5,en;q=0.3',
                    'Accept-Encoding':'gzip, deflate',
                    'Connection':'keep-alive',
                    'DNT':'1'}
                session = requests.session()
                data = session.get(url, headers=headers)
                page = lxml.html.fromstring(data.content)

                form = page.forms[0]
                form.fields['email'] = login
                form.fields['pass'] = password

                response = session.post(form.action, data=form.form_values())
                if 'onLoginDone' in response.text:
                        self.session = session
                else:
                        raise PermissionError("login or password is wrong")

                self.hash = hashe(self.session)
        def code(self,code):
                """вызывает метод execute."""
                q =  self.session.post(
                        "https://vk.com/dev/execute?params[code]="+code+"&params[v]=5.87",
                        data={"act": "a_run_method",
                              "al": 1,
                              "method":"execute",
                              "param_code": code,
                              "param_v": 5.87,
                              "hash": self.hash},headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:62.0) Gecko/20100101 Firefox/62.0','Accept': '*/*',
                                                        'Accept-Language': 'en-US,en;q=0.5','Accept-Encoding': 'gzip, deflate, br','Content-Type': 'application/x-www-form-urlencoded','Connection': 'keep-alive',
                })
                
                audio = json.loads(q.text[38:len(q.text)])
                if "response" in audio:
                        return audio["response"]
                else:
                        return audio
        def get(self,owner_id= None,album_id =None,NeedUser =False ):
                """вызывает метод auido.get"""
                """owner_id - id пользователя или
                        группы( отрицательные значения
                album_id - id альбома
                NeedUser - если True, то возращает информацию о исполнители песен"""
                code_response = ""
                if owner_id:
                        code_response += "owner_id:"+str(owner_id)
                if album_id:
                        code_response += ",album_id:"+str(album_id)
                if NeedUser:
                        code_response += ",NeedUser:1"
                q = code_response.lstrip(",")
                
                code = r'return API.audio.get({'+q+r'});'
                return self.code(code)
        def search(self,q='imagine dragons',owner_id=None,offset=0,PerformerOnly=False,):
                code_response = ""
                code_response+='q:"{q}"'.format(q=q)
                if owner_id:
                        code_response += ",owner_id:"+str(owner_id)
                if PerformerOnly:
                        code_response += ",PerformerOnly:1"
                if offset!=0:
                        if str(offset).isdsgst():
                                code_response += ",NeedUser:1"
                        else:
                                raise NameError("offset has to be an digit")
                
                
                code_response = code_response.lstrip(",")

                code = r'return API.audio.search({'+code_response+r'});'
                
                return self.code(code)
        def add(self,owner_id=1234567,audio_id=456239029):
                code_response = ""
                code_response += "owner_id:{owner_id},audio_id:{audio_id}".format(owner_id=str(owner_id),audio_id=str(audio_id))
                code = r'return API.audio.add({'+code_response+r'});'
                
                return self.code(code)
	
def hashe(session):
        qw = session.get("https://vk.com/dev/execute").text
        return re.findall('onclick="Dev.methodRun\(\'(.+)\', this\);"',qw)[0]






import random
import datetime
import time
def get_time():
    def strTimeProp(start, end, format, prop):
        stime = time.mktime(time.strptime(start, format))
        etime = time.mktime(time.strptime(end, format))

        ptime = stime + prop * (etime - stime)

        return time.strftime(format, time.localtime(ptime))


    def randomDate(start, end, prop):
        return strTimeProp(start, end, '%m/%d/%Y %I:%M %p', prop)

    return randomDate(datetime.datetime.strftime(datetime.datetime.today(),'%m/%d/%Y %I:%M %p'), datetime.datetime.strftime(datetime.datetime.today()+datetime.timedelta(days=10000),'%m/%d/%Y %I:%M %p'), random.random())
    

class chat():
    def random_chat_person(vk,chat_id):
        info = vk.method("messages.getConversationMembers",{"peer_id":chat_id})
        
        count_id=[] 
        
        for i in info["profiles"]:
            
            
            count_id.append("И этот человек:\n@id{id}({last_name} {first_name})".format(id = str(i["id"]),last_name=i["last_name"],first_name=i["first_name"]))
            
        return random.choice(count_id)
    def random_date():
        return "И это случиться "+ get_time()
    def True_Flase():
        return random.choice(["и это правда!!!", "и это неправда!!!"])





import bot_vk
data = [None]
import requests
from datetime import datetime
def unixtime_converter(time):
    
    return (datetime.utcfromtimestamp(int(time+10800))).strftime('%Y-%m-%d %H:%M:%S')
def compucter_opredeli(num):
    if num == 1:
        return "mobile"
    elif num == 2:
        return "iphone"
    elif num == 7:
        return "web"
    elif num == 6:
        return "windows"
    elif num == 5:
        return "wphone"
    elif num == 3:
        return "ipad"
    elif num == 4:
        return "android"
def message_flag(flag):
    if flag == 128:
        return "message_delete"
    elif flag == 1:
        return "message_unread"
    elif flag == 2:
        return "message_fromMe"
    elif flag == 4:
        return "message_newAnswer"
    elif flag == 65536:
        return "group_whant_to_message_you"
    elif flag == 8:
        return "import_message"
    elif flag == 16:
        return "new_chatMessage"
    elif flag == 32:
        return "message_Fromfriend"
    elif flag == 64:
        return "spam_message"
    elif flag == 131072:
        return "message_deletedForAll"
    else:
        return "not_definded"
class longpoll():

    def user_longpoll(vk):
        
        """модуль для облегчения жизни и использования longpoll_api"""
        if data[0]== None:
            data[0] = vk.method("messages.getLongPollServer",{})
        try:
            dfyi = True
            response = requests.get('https://{server}?act=a_check&key={key}&ts={ts}&wait=20&mode=2&version=2'.format(server=data[0]['server'], key=data[0]['key'], ts=data[0]['ts'])).json()  # отправление запроса на Long Poll сервер со временем ожидания 20 и опциями ответа 2
            updates = response['updates']
        except:
            dfyi = False
            data[0] = vk.method("messages.getLongPollServer",{})
        if dfyi == True:
            s = []
            if updates:  # проверка, были ли обновления
                for element in updates:  # проход по всем обновлениям в ответе
                    s.append(element)
                data[0]['ts'] = response['ts']
                
                otvet1=[]
                for i in range(len(s)):
                    otvet = {}
                    types = s[i][0]
                    
                    if types == 4:
                        info1 = vk.method("messages.getById",{
                            "message_ids":s[i][1]})["items"][0]
                        otvet["type"] = "message_new"
                        otvet["params"] = info1
                    elif types == 8:
                        otvet["type"] = "friend_online"
                        otvet["params"] = {"peer_id":-s[i][1],
                                           "time":unixtime_converter(s[i][3]),
                                           "type":compucter_opredeli(s[i][2])}
                    elif types == 9:
                        otvet["type"] = "friend_offline"
                        if s[i][2] == 0:
                            xima ="offline by leave"
                        if s[i][2] == 1:
                            xima = "offline by timeout"
                        otvet["params"] = {"peer_id":-s[i][1],
                                           "time":unixtime_converter(s[i][3]),
                                           "offline_type":xima}
                        
                    elif types == 13:
                        otvet["type"] = "messages_all_deleted"
                    elif types == 14:
                        otvet["type"] = "message_restored"
                    elif types == 51:
                        otvet["type"] = "chat_edit"
                    elif types == 61:
                        otvet["type"] = "message_type"
                        otvet["params"]={"peer_id":s[i][1]}
                    elif types == 62:
                        otvet["type"] = "message_type_chat"
                    elif types == 80:
                        otvet["type"] = "messages_count"
                        otvet["params"] ={"count":s[i][1]}
                    elif types == 112 :
                        otvet["type"] = "notifications_change"
                    elif types == 3 or types ==2:
                        if len(s[i])>=3:
                            
                                if s[i][3] > 200000000:
                                    id_bot = s[i][3]
                                else:
                                    id_bot = -s[i][3]
                                otvet["type"] = message_flag(s[i][2])
                                otvet["params"] = {"message_id":s[i][1],
                                                   "peer_id":id_bot 
                                              }
                        else:
                            otvet["type"] = message_flag(s[i][2])
                            
                    elif types == 6 or types == 7:
                        otvet["type"] = "message_readed"
                    else:
                        otvet["type"]= "not_definded"
                    otvet1.append(otvet)
                    otvet = {}
                if 1 == 1:
                    if otvet1 != {}:
                        return otvet1
                    else:
                        return None             
            
        
    def longpoll_bot(szenarii1,szenarii2,message_neznayu="я не знаю, как ответить(((",attachment_neznayu="doc302808715_475715032",attachments = None,vk=None,login=None,password=None,token=None):
        """чат-бот с использованием longpoll api"""
        """
        szenarii1 - list в котором лежат сценарии(варианты того, что может прислать пользователь)
        szenarii2 - list, в котором лжат ответы на сценарии(на первый элемент
            szenarii1 будет отвечен первый элемент szenarii1, длина массива szenarii2 должна быть равна
                длине szenarii1
        message_neznayu - строка, в которой ответ на все другие сообщения, не считая 
        attachment_neznayu - attachment, который пошлется, если 




        """

        if len(szenarii1)!=len(szenarii2):
            raise OSError("длина szenarii2 должна быть равна длене szenarii1")
        if vk ==None:
            if token!=None:
                vk = bot_vk.auth_vk(token = token)
            elif login!=None and password!=None:
                vk = bot_vk.auth_vk(login = login,password = password)
                
            else:
                raise OSError("нужен или логин с паролем или токен или параметр vk")
        if attachments == None:
            attachments=[""]*len(szenarii1)
        
        id_own = vk.method("users.get",{})[0]["id"]
        
        while True:
            info =bot_vk.longpoll.user_longpoll(vk)
            
            if info != None:
                q = 0
                
                for i in info:
                    if i["type"] == "message_new":
                        
                        q = 1
                        info = i
                        break
                
                if q ==1:
                    if info["params"]["out"] == 1:
                        continue
                    
                    id = info["params"]["peer_id"]
                    message = info["params"]["text"]
                    if id != id_own and id>0:
                        
                        ininon = vk.method("users.get",{"user_ids":id,"fields":"id,city,sex"})[0]
                        firstname = ininon["first_name"]
                        lastname =ininon["last_name"]
                        if "city" in ininon:
                            city = ininon["city"]["title"]
                        else:
                            city = "Москва"
                        pol = ininon["sex"]
                        

                        
                        s = 1
                        
                        for i in range(len(szenarii1)):
                            mes =szenarii1[i]
                            if mes.lower() == message.lower():
                                s = 0
                                
                                string = bot_vk.parse(szenarii2[i], pol).format(firstname=firstname,lastname=lastname,city=city)
                                                                     
                                vk.method("messages.send",{"message":string,"peer_id":id,"attachment": attachments[i]})
                                
                                break
                                        
                        if s == 1:
                            
                            string = bot_vk.parse(message_neznayu, pol).format(firstname=firstname,lastname=lastname,city=city)
                            
                            vk.method("messages.send",{"message":string,"peer_id":id,"attachment":attachment_neznayu})
                           
                 



from setuptools import setup,find_packages
# __init__.py
__version__ = "1.6"
setup(name='bot_vk',
      version='1.6',
      description='Легкое создание чат-ботов и др. Документация: vk.com/@bot_vk_python-doc-1-6',
      long_description='Этот модуль позволит вам без труда создать своего чат-бота вконтакте. Документация: vk.com/@bot_vk_python-doc-1-6',
      classifiers=[
          'Development Status :: 3 - Alpha',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 3.6', 'Topic :: Text Processing :: Linguistic',
                    ],
      keywords='vk, vk_api, vk_bot,bot_vk',
      url='https://vk.com/@bot_vk_python-doc-1-6', author='ivan martemyanov',
      author_email='imartemy152@gmail.com',
      license='MIT',
      packages=find_packages(),
      install_requires=[
          'vk_api',
          'requests',
          'datetime',
          'lxml',
          'requests'
          
      ],
      include_package_data=True,
      zip_safe=False
)



from .keyboard_for_bot import keyboard
from .bot_python import internet_on,auth_vk,dele,vk_bot,parse
from .bot_longpoll import longpoll
from .chat_bot import chat
from .music import audio

music,bot_longpoll,bot_python,keyboard_for_bot,chat_bot = None,None,None,None,None
globals().pop("bot_longpoll"),globals().pop("chat_bot"),globals().pop("bot_python"),globals().pop("keyboard_for_bot"),globals().pop("music")


__version__ = "1.6"
__email__ = "imartemy1524@gmail.com"
__vk__ = "https://vk.com/imartemy"
__doc__="https://vk.com/@bot_vk_python-doc-1-6"
__url__="https://vk.com/@bot_vk_python-doc-1-6"
name="bot_vk"



import random
import json
class keyboard():
    def get(text, side,color = None,one_time = True):
        """модуль позволяет создать свою клавиатуру"""
        """
        text - list, в котором каждый элемент соответствует своей кнопке. Пример:
                list = ["начать","назад"]
        color - list, в котором каждый элемент соответствует цвету кнопки.
            Если не передано, то генерируется случайное значение. 
        side - на каком уровне находится кнопка. На одном уровне больше 4-х кнопок недопустимо. Пример:
                side = [1,1,1,2,3]
        one_time - сразу ли исчезнит клавиатура. Если False - то нет.Если вы набрали False, а потом хотите. чтобы она исчезла, то в параметре клавиатуры
            передайте функцию keyboard_none(ниже)
        """
        
        count = len(text)
        if color == None:
            s = ["default","negative","primary","positive"]
            color = []
            for i in range(count):
                color.append(random.choice(s))
        for i in range(len(color)):
            if color[i].lower() == "green":
                color[i] = "positive"
            elif color[i].lower()== "blue":
                color[i] = "primary"
            elif color[i].lower() == "white":
                color[i] = "default"
            elif color[i].lower() ==  "red":
                color[i] = "negative"
        """
        if side == None:
            
            side = []
            for i in range(count):
                side.append(i+1)
        """        
        if len(color) == len(text):
            def get_button(label, color, payload=""):
                return {
                    "action": {
                        "type": "text",
                        'payload': json.dumps(payload),
                        "label": label
                    },
                    "color": color
                }
            def get(count):
                zi = []
                cou = 1
                s1 = []
                for i in range(count):
                    
                    if cou == side[i]:
                        
                        s1.append(get_button(label = text[i],color = color[i]))
                    else:
                        zi.append(s1)
                        s1 = []
                        cou +=1
                        s1.append(get_button(label = text[i],color = color[i]))
                zi.append(s1)
                return zi
            keyboard_hello = {
            "one_time": one_time,
            "buttons": get(count)
            }
            keyboard_hello  = json.dumps(keyboard_hello, ensure_ascii=False).encode('utf-8')
            keyboard_hello = str(keyboard_hello.decode('utf-8'))

            return keyboard_hello
    def keyboard_none():
        """модуль возращает пустую клавиатуру"""
        keyboard_None = {
            "one_time": True,
            "buttons": []
        }
        keyboard_None  = json.dumps(keyboard_None, ensure_ascii=False).encode('utf-8')
        keyboard_None = str(keyboard_None.decode('utf-8'))
        return keyboard_None             
            
